Module format

Module format 

Data format readers and writers.

Supported formats: JSON, JSON Lines, CSV/TSV, YAML, TOML, XML, MessagePack, Excel (xlsx, read-only), SQLite (read-only), Apache Parquet, Markdown (write-only), HTML (write-only).

Modules

csv
CSV/TSV reader and writer.
env
.env file reader and writer.
hcl
Stub module — HCL feature not enabled.
html
HTML table writer.
ini
INI/CFG configuration file reader and writer.
json
JSON reader, writer, and value conversion utilities.
jsonl
JSON Lines (NDJSON) reader and writer.
log
Log file reader (Apache, nginx, syslog, custom patterns).
markdown
Markdown table writer.
msgpack
Stub module — MessagePack feature not enabled.
parquet
Stub module — Parquet feature not enabled.
plist
Stub module — plist feature not enabled.
properties
Java .properties file reader and writer.
sqlite
Stub module — SQLite feature not enabled.
toml
TOML reader and writer.
xlsx
Stub module — Excel feature not enabled.
xml
Stub module — XML feature not enabled.
yaml
YAML reader and writer.

Structs

FormatOptions
Format-specific options controlling how data is read or written.

Enums

Format
Supported data formats for reading and writing.

Traits

FormatReader
Trait for reading a data format into a Value.
FormatWriter
Trait for writing a Value to a data format.

Functions

default_delimiter
파일 확장자에 따른 기본 delimiter 반환 .tsv 파일은 탭 구분자를 사용한다.
default_delimiter_for_format
--to 포맷 문자열에 따른 기본 delimiter 반환
detect_format
파일 확장자로 포맷을 자동 감지
detect_format_from_content
콘텐츠 스니핑으로 포맷을 자동 감지