Format

Enum Format 

#[non_exhaustive]
pub enum Format {
Show 18 variants Json, Jsonl, Csv, Yaml, Toml, Xml, Msgpack, Xlsx, Sqlite, Parquet, Markdown, Html, Table, Env, Ini, Properties, Hcl, Plist,
}
Supported data formats for reading and writing.

Each variant represents a data serialization format that dkit can convert to or from the unified Value model.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Json

JSON (*.json)



Jsonl

JSON Lines / NDJSON (*.jsonl, *.ndjson)



Csv

Comma/Tab-separated values (*.csv, *.tsv)



Yaml

YAML (*.yaml, *.yml)



Toml

TOML (*.toml)



Xml

XML (*.xml)



Msgpack

MessagePack binary format (*.msgpack)



Xlsx

Excel spreadsheet (*.xlsx, read-only)



Sqlite

SQLite database (*.sqlite, read-only)



Parquet

Apache Parquet columnar format (*.parquet)



Markdown

Markdown table (write-only)



Html

HTML table (write-only)



Table

Terminal table (write-only, used by dkit view)



Env

.env file format (*.env, .env.*)



Ini

INI/CFG configuration file format (*.ini, *.cfg)



Properties

Java .properties file format (*.properties)



Hcl

HCL (HashiCorp Configuration Language) (*.hcl, *.tf, *.tfvars)



Plist

macOS Property List (*.plist)

Implementations

Source

impl Format

pub fn from_str(s: &str) -> Result<Self, DkitError>

pub fn list_output_formats() -> Vec<(&'static str, &'static str)>

사용 가능한 출력 포맷 목록을 반환한다